powered by
Prepare data for baseline characteristic table
prepare_base_char( meta, analysis = "base_char", population = meta$plan[meta$plan$analysis == analysis, ]$population, parameter = paste(meta$plan[meta$plan$analysis == analysis, ]$parameter, collapse = ";") )
A list of analysis raw datasets.
A metadata object created by metalite.
A character value of analysis term name. The term name is used as key to link information.
A character value of population term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
meta <- meta_sl_example() meta |> prepare_base_char()
Run the code above in your browser using DataLab