Learn R Programming

metalite.sl (version 0.1.0)

prepare_sl_summary: Prepare data for baseline characteristic table

Description

Prepare data for baseline characteristic table

Usage

prepare_sl_summary(
  meta,
  population,
  analysis,
  parameter = paste(names(meta$parameter), collapse = ";")
)

Value

A list of analysis raw datasets.

Arguments

meta

A metadata object created by metalite.

population

A character value of population term name. The term name is used as key to link information.

analysis

A character value of analysis term name. The term name is used as key to link information.

parameter

A character value of parameter term name. The term name is used as key to link information.

Examples

Run this code
meta <- meta_sl_example()
meta |> prepare_sl_summary(population = "apat", analysis = "base_char")

Run the code above in your browser using DataLab