Baseline characteristic table
Usage
rtf_base_char(
outdata,
source,
col_rel_width = NULL,
text_font_size = 9,
orientation = "portrait",
footnotes = NULL,
title = NULL,
path_outdata = NULL,
path_outtable = NULL
)Arguments
- outdata
An
outdataobject created byprepare_sl_summary().- source
A character value of the data source.
- col_rel_width
Column relative width in a vector e.g. c(2,1,1) refers to 2:1:1. Default is NULL for equal column width.
- text_font_size
Text font size. To vary text font size by column, use numeric vector with length of vector equal to number of columns displayed e.g. c(9,20,40).
- orientation
Orientation in 'portrait' or 'landscape'.
- footnotes
A character vector of table footnotes.
- title
Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.
- path_outdata
A character string of the outdata path.
- path_outtable
A character string of the outtable path.
Examples
meta <- metalite::meta_adam(
population = metalite_sl_adsl,
observation = metalite_sl_adsl
) |>
metalite::define_plan(metalite::plan(
analysis = "base_char", population = "apat",
observation = "apat", parameter = "age;gender"
)) |>
metalite::define_population(
name = "apat", group = "TRTA", subset = SAFFL == "Y"
) |>
metalite::define_parameter(
name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
) |>
metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
metalite::define_analysis(
name = "base_char",
title = "Participant Baseline Characteristics by Treatment Group"
) |>
metalite::meta_build()
#> Warning: base_char: has missing label
meta |>
prepare_base_char(
population = "apat",
analysis = "base_char",
parameter = "age;gender"
) |>
format_base_char() |>
rtf_base_char(
source = "Source: [CDISCpilot: adam-adsl]",
path_outdata = tempfile(fileext = ".Rdata"),
path_outtable = tempfile(fileext = ".rtf")
)
#> The outdata is saved in/tmp/RtmpbEVefW/file1a8ce6a1e95.Rdata
#> The output is saved in/tmp/RtmpbEVefW/file1a8c3cb887ec.rtf