Learn R Programming

metalite.sl (version 0.1.0)

collect_baseline: Count number of subjects

Description

Count number of subjects

Usage

collect_baseline(
  meta,
  population,
  parameter,
  type = "Subjects",
  use_na = c("ifany", "no", "always"),
  display_total = TRUE
)

Value

A list containing number of subjects

Arguments

meta

A metadata object created by metalite.

population

A character value of population term name. The term name is used as key to link information.

parameter

A character value of parameter term name. The term name is used as key to link information.

type

A character value to control title name, e.g., Subjects or Records.

use_na

A character value for whether to include NA values in the table. See the useNA argument in base::table() for more details.

display_total

A logical value to display total column.

Examples

Run this code
meta <- meta_sl_example()
meta |> collect_baseline(
  population = "apat",
  parameter = "age"
)

Run the code above in your browser using DataLab