powered by
Count number of subjects
collect_baseline( meta, population, parameter, type = "Subjects", use_na = c("ifany", "no", "always"), display_total = TRUE )
A list containing number of subjects
A metadata object created by metalite.
A character value of population term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
A character value to control title name, e.g., Subjects or Records.
A character value for whether to include NA values in the table. See the useNA argument in base::table() for more details.
NA
useNA
base::table()
A logical value to display total column.
meta <- meta_sl_example() meta |> collect_baseline( population = "apat", parameter = "age" )
Run the code above in your browser using DataLab