Create metadata for subject-level analysis table
meta_sl(
dataset_population,
dataset_observation = NULL,
population_term,
observation_term = NULL,
parameter_term = "age;race;gender",
parameter_var = "AGE^AGEGR1;RACE;SEX",
parameter_labels = NULL,
analysis_term = "base_char",
analysis_title = "Participant Baseline Characteristics by Treatment Group",
population_subset = SAFFL == "Y",
observation_subset = NULL,
population_label = "All Participants as Treated",
treatment_group = "TRT01A"
)A metalite object.
Source dataset of population.
Source dataset of observation
A character value of population term name.
A character value of observation term name.
A character value of parameter term name. If there are multiple terms, they are separated by the semicolon (;).
A character value of parameter variable name. If there are multiple variables, they are separated by the semicolon (;). A group variable can be specified followed by a variable and the hat symbol (^).
A character vector of parameter label name.
The length of vector should be the same as the number of parameter terms.
A label from an input data is used if NA for a variable is specified.
A character value of analysis term name.
A character value of analysis title name.
An unquoted condition for selecting the populations from dataset of population.
An unquoted condition for selecting the populations from dataset of observation
A character value of population label.
A character value of treatment group name.
meta_sl(
dataset_population = r2rtf::r2rtf_adsl,
population_term = "apat",
parameter_term = "age;race",
parameter_var = "AGE^AGEGR1;RACE"
)
Run the code above in your browser using DataLab