powered by
Prepare data for baseline characteristic table
prepare_sl_summary( meta, population, analysis, parameter = paste(names(meta$parameter), collapse = ";") )
A list of analysis raw datasets.
A metadata object created by metalite.
A character value of population term name. The term name is used as key to link information.
A character value of analysis term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
meta <- meta_sl_example() meta |> prepare_sl_summary(population = "apat", analysis = "base_char")
Run the code above in your browser using DataLab